#include "log.h"
#include "lephisto.h"
#include "toolkit.h"
#include "space.h"
#include "opengl.h"
#include "map.h"

#define MAP_WIDTH			500
#define MAP_HEIGHT		400

#define BUTTON_WIDTH	60
#define BUTTON_HEIGHT	40

static int 		map_wid 	= 0;
static double map_xpos 	= 0.;
static double map_ypos 	= 0.;

// Extern.
extern StarSystem* systems_stack;
extern int systems_nstack;

void map_render(double bx, double by, double w, double h);
void map_close(char* str);

// Open the map window.
void map_open(void) {
	if(map_wid) map_close(NULL);

	// Set the position to focus on current system.
	map_xpos = cur_system->pos.x + (MAP_WIDTH-120)/2;
	map_ypos = cur_system->pos.y + (MAP_HEIGHT-60)/2;

	map_wid = window_create("Star Map", -1, -1, MAP_WIDTH, MAP_HEIGHT);

	window_addCust(map_wid, 20, 20, MAP_WIDTH - 120, MAP_HEIGHT - 60,
				"cstMap", 1, map_render);
	window_addButton(map_wid, -20, 20, BUTTON_WIDTH, BUTTON_HEIGHT,
				"btnClose", "Close", map_close);
}

void map_close(char* str) {
	(void)str;
	if(map_wid) {
		window_destroy(map_wid);
		map_wid = 0;
	}
}

// Render the map as a custom widget.
void map_render(double bx, double by, double w, double h) {
	int i;
	// Background
	COLOUR(cBlack);
	glBegin(GL_QUADS);
		glVertex2d(bx, 		by);
		glVertex2d(bx, 		by+h);
		glVertex2d(bx+w, 	by+h);
		glVertex2d(bx+w,	by);
	glEnd();

	COLOUR(cYellow);
	for(i = 0; i < systems_nstack; i++)
		gl_drawCircleInRect(systems_stack[i].pos.x, systems_stack[i].pos.y,
					5, bx, by, w, h);
}

